DatabaseConnection

Enum DatabaseConnection 

pub enum DatabaseConnection {
    Disconnected,
}
Handle a database connection depending on the backend enabled by the feature flags. This creates a database pool. This will be Clone unless the feature flag mock is enabled.

Variants



Disconnected

The connection to the database has been severed

Implementations

Source

impl DatabaseConnection

pub fn set_metric_callback<F>(&mut self, _callback: F)
where F: Fn(&Info<'_>) + Send + Sync + 'static,

Sets a callback to metric this connection

pub async fn ping(&self) -> Result<(), DbErr>

Checks if a connection to the database is still valid.

pub async fn close(self) -> Result<(), DbErr>

Explicitly close the database connection. See Self::close_by_ref for usage with references.

pub async fn close_by_ref(&self) -> Result<(), DbErr>

Explicitly close the database connection