load_checkpoint

Function load_checkpoint 

pub async fn load_checkpoint(
    db: &DatabaseConnection,
    key: &str,
) -> Result<Option<DateTime<Utc>>, DatabaseError>
Load the checkpoint timestamp for a key from the graph_sync_checkpoints table, or None if the key does not exist.