pub async fn seed_tutorials_if_first_call(
db: &dyn NotebookDb,
user_id: Uuid,
) -> Result<(), DatabaseError>Expand description
Seed the two tutorial notebooks for user_id if not already present.
Idempotent: if both tutorial ids already exist for this owner, this is
a no-op. If either is missing it is inserted with the deterministic UUID5
id and deletable=false.